import { Request, Response } from "express";
import Store from "../models/store";
import { getUserSession } from "../utils/utils";
import { isCompanyNameValid } from "../validator/validator";

export async function GetStore(req: Request, res: Response) {
  try {
    const { storeId } = req.params;

    if (!storeId) {
      return res.status(400).send({ err: "invalid request" });
    }

    // check if requester is the store owner

    const userSession = await getUserSession(req);

    if (!userSession) {
      return res.status(401).send({ err: "unauthorized" });
    }

    const store = await Store.findOne({
      where: {
        store_id: storeId,
      },
      attributes: ["owner_user_id", "name", "phone_number", "email", "address"],
    });

    if (!store) {
      return res.status(400).send({ err: "invalid request" });
    }

    if (store.owner_user_id !== userSession.user_id) {
      return res.status(401).send({ err: "unauthorized" });
    }

    res.status(200).send({
      store: {
        name: store.name,
        phone_number: store.phone_number,
        email: store.email,
        address: store.address,
      },
    });
  } catch (error) {
    res.status(500).send({ err: "invalid request" });
  }
}

export async function UpdateStore(req: Request, res: Response) {
  try {
    const { storeId } = req.params;
    const { name, phoneNumber, email, address } = req.body;

    // validate request

    if (!isCompanyNameValid(name)) {
      return res.status(400).send({ err: "invalid request" });
    }

    // check if requester is the store owner

    const userSession = await getUserSession(req);

    if (!userSession) {
      return res.status(401).send({ err: "unauthorized" });
    }

    const store = await Store.findOne({
      where: {
        store_id: storeId,
      },
      attributes: ["owner_user_id"],
    });

    if (!store) {
      return res.status(400).send({ err: "invalid request" });
    }

    if (store.owner_user_id !== userSession.user_id) {
      return res.status(401).send({ err: "unauthorized" });
    }

    await Store.update(
      {
        name,
        phone_number: phoneNumber,
        email,
        address,
      },
      {
        where: {
          store_id: storeId,
        },
      }
    );

    res.status(200).send({ msg: "success" });
  } catch (error) {
    res.status(500).send({ err: "invalid request" });
  }
}
