import { DataTypes, Model } from "sequelize";
import sequelize from "../database/database";

interface EmailVerificationAttributes {
  email_verification_id: string; // code that is sent to the user's email
  user_id: string;
  state: number; // to know for what the code is used for (like password reset, email verification, etc)
}

class EmailVerification
  extends Model<EmailVerificationAttributes>
  implements EmailVerificationAttributes
{
  declare email_verification_id: string;
  declare user_id: string;
  declare state: number;
}

EmailVerification.init(
  {
    // Model attributes are defined here
    email_verification_id: {
      primaryKey: true,
      type: DataTypes.STRING,
      allowNull: false,
    },
    user_id: {
      type: DataTypes.STRING,
      allowNull: false,
    },
    state: {
      type: DataTypes.TINYINT,
      allowNull: false,
    },
  },
  {
    tableName: "email_verification",
    sequelize, // passing the `sequelize` instance is required
    createdAt: "created_at",
    updatedAt: "updated_at",
  }
);

export default EmailVerification;
