import { DataTypes, Model } from "sequelize";
import sequelize from "../database/database";

interface StoreAttributes {
  store_id: string;
  owner_user_id: string;
  name: string;
  phone_number?: string;
  email?: string;
  address?: string;
  calendar_max_future_booking_days: number;
  calendar_min_earliest_booking_time: number;
  //calendar_primary_calendar_id?: string;
  //calendar_using_primary_calendar: boolean;
  calendar_max_service_duration: number;
}

class Store extends Model<StoreAttributes> implements StoreAttributes {
  declare store_id: string;
  declare owner_user_id: string;
  declare name: string;
  declare phone_number: string;
  declare email: string;
  declare address: string;
  declare calendar_max_future_booking_days: number;
  declare calendar_min_earliest_booking_time: number;
  //declare calendar_primary_calendar_id: string;
  //declare calendar_using_primary_calendar: boolean;
  declare calendar_max_service_duration: number;
}

Store.init(
  {
    // Model attributes are defined here
    store_id: {
      primaryKey: true,
      type: DataTypes.STRING,
      allowNull: false,
    },
    owner_user_id: {
      type: DataTypes.STRING,
      allowNull: false,
    },
    name: {
      type: DataTypes.STRING,
      allowNull: false,
    },
    phone_number: {
      type: DataTypes.STRING,
      // allowNull defaults to true
    },
    email: {
      type: DataTypes.STRING,
      // allowNull defaults to true
    },
    address: {
      type: DataTypes.STRING,
      // allowNull defaults to true
    },
    calendar_max_future_booking_days: {
      type: DataTypes.INTEGER,
      allowNull: false,
    },
    calendar_min_earliest_booking_time: {
      type: DataTypes.INTEGER,
      allowNull: false,
    },
    /*calendar_primary_calendar_id: {
      type: DataTypes.STRING,
      // allowNull defaults to true
    },
    calendar_using_primary_calendar: {
      type: DataTypes.BOOLEAN,
      allowNull: false,
    },*/
    calendar_max_service_duration: {
      type: DataTypes.INTEGER,
      allowNull: false,
    },
  },
  {
    tableName: "stores",
    sequelize, // passing the `sequelize` instance is required
    createdAt: "created_at",
    updatedAt: "updated_at",
  }
);

export default Store;
