import { DataTypes, Model } from "sequelize";
import sequelize from "../database/database";
import StoreServiceActivityUsers from "./storeServiceActivityUsers";

interface StoreServiceActivityAttributes {
  activity_id: string;
  service_id: string;
  name: string;
  description?: string;
  price: number;
  duration: number;
}

class StoreServiceActivity
  extends Model<StoreServiceActivityAttributes>
  implements StoreServiceActivityAttributes
{
  declare activity_id: string;
  declare service_id: string;
  declare name: string;
  declare description: string;
  declare price: number;
  declare duration: number;
}

StoreServiceActivity.init(
  {
    // Model attributes are defined here
    activity_id: {
      primaryKey: true,
      type: DataTypes.STRING,
      allowNull: false,
    },
    service_id: {
      type: DataTypes.STRING,
      allowNull: false,
    },
    name: {
      type: DataTypes.STRING,
      allowNull: false,
    },
    description: {
      type: DataTypes.TEXT,
      allowNull: true,
    },
    price: {
      type: DataTypes.FLOAT,
      allowNull: false,
    },
    duration: {
      type: DataTypes.INTEGER,
      allowNull: false,
    },
  },
  {
    tableName: "store_service_activities",
    sequelize, // passing the `sequelize` instance is required
    createdAt: "created_at",
    updatedAt: "updated_at",
  }
);

// create associations
StoreServiceActivity.hasMany(StoreServiceActivityUsers, {
  foreignKey: "activity_id",
});

export default StoreServiceActivity;
