import express, { Request } from "express";
import passport from "passport";
const router = express.Router();
import logger from "../logger/logger";
import Session from "../models/session";

import * as calendarController from "../controllers/calendarController";
import {
  PASSPORT_FAILURE_REDIRECT_URL,
  PASSPORT_SUCCESS_REDIRECT_URL,
} from "../utils/constants";
import User from "../models/user";
import { terminPlanerRequest } from "../utils/terminPlaner";
import { sessionProtection } from "../middleware/authMiddleware";

router.get(
  "/auth/google",
  passport.authenticate("google", {
    accessType: "offline",

    //session: false,
    scope: [
      "https://www.googleapis.com/auth/calendar.app.created",
      "https://www.googleapis.com/auth/calendar.events.freebusy",
      "https://www.googleapis.com/auth/userinfo.profile",
    ],
  })
);

router.get(
  "/auth/google/callback",
  passport.authenticate("google", {
    failureRedirect: PASSPORT_FAILURE_REDIRECT_URL,
  }),
  function (req, res) {
    // Successful authentication, redirect home
    const sessionId = req.cookies["session"];

    if (!sessionId) {
      logger.error("session cookie not found");
      res.redirect(PASSPORT_FAILURE_REDIRECT_URL);
      return;
    }

    const accessToken = (req.user as Request & { accessToken?: string })
      .accessToken;
    const refreshToken = (req.user as Request & { refreshToken?: string })
      .refreshToken;
    const sub = (req.user as Request & { profile?: any }).profile._json.sub; // google user id

    const googleAccountName = (req.user as Request & { profile?: any }).profile
      ._json.name;
    const googleAccountPicture = (req.user as Request & { profile?: any })
      .profile._json.picture;

    Session.findOne({
      where: {
        session_id: sessionId,
      },
    })
      .then(async (userSession) => {
        if (!userSession) {
          logger.error("user session not found");
          res.redirect(PASSPORT_FAILURE_REDIRECT_URL);
          return;
        }

        terminPlanerRequest("/api/v1/addGoogleAccount", "POST", {
          userId: userSession.user_id,
          accessToken: accessToken,
          refreshToken: refreshToken,
          sub: sub,
        });

        User.findOne({
          where: {
            user_id: userSession.user_id,
          },
        })
          .then((user) => {
            if (!user) {
              logger.error("user not found");
              return;
            }

            user.google_account_name = googleAccountName;
            user.google_account_picture = googleAccountPicture;

            user.save().catch((err) => logger.error(err));
          })
          .catch((err) => {
            logger.error(err);
            res.redirect(PASSPORT_FAILURE_REDIRECT_URL);
          });

        res.redirect(PASSPORT_SUCCESS_REDIRECT_URL);
      })
      .catch((err) => {
        logger.error(err);
        res.redirect(PASSPORT_FAILURE_REDIRECT_URL);
      });

    // /api/v1/addGoogleAccount
  }
);

router.get("/store", sessionProtection, calendarController.GetStoreId);
router.get(
  "/settings",
  sessionProtection,
  calendarController.GetCalendarSettings
);
router.post(
  "/settings/personal",
  sessionProtection,
  calendarController.UpdatePersonalCalendarSettings
);
router.post(
  "/settings/store",
  sessionProtection,
  calendarController.UpdateStoreCalendarSettings
);
router.post(
  "/settings/personal/unlink",
  sessionProtection,
  calendarController.UnlinkGoogleCalendar
);

export default router;
