import express from "express";
const router = express.Router();

import * as userController from "../controllers/userController";
import { sessionProtection } from "../middleware/authMiddleware";

router.post("/auth/signup", userController.SignUp);
router.post("/auth/login", userController.Login);
router.post("/auth/forgot-password", userController.ForgotPassword);
router.delete("/auth/logout", sessionProtection, userController.Logout);
router.get("/", sessionProtection, userController.GetUser);
router.post("/auth/check/email", userController.IsEmailAvailable);
router.get(
  "/profile/settings",
  sessionProtection,
  userController.GetUserProfileSettings
);
router.post(
  "/profile/settings",
  sessionProtection,
  userController.UpdateUserProfileSettings
);
router.post(
  "/profile/password",
  sessionProtection,
  userController.UpdateUserProfilePassword
);
router.post(
  "/profile/email",
  sessionProtection,
  userController.UpdateUserProfileEmail
);
router.get(
  "/profile/sessions",
  sessionProtection,
  userController.GetUserProfileSessions
);
router.delete(
  "/profile/sessions/:id",
  sessionProtection,
  userController.DeleteUserProfileSession
);
router.delete(
  "/profile/delete",
  sessionProtection,
  userController.DeleteUserProfile
);
router.post(
  "/profile/export",
  sessionProtection,
  userController.ExportUserAccount
);
router.get("/profile/export/:id", userController.GetExportedUserAccount);
router.post("/verify/:state/:emailVerificationId", userController.VerifyEmail);

export default router;
